@@ -742,7 +742,7 @@ def test_positions(comm):
     nx, ny = (12 * comm.Get_size(), 10 * comm.Get_size() + 1)
     sx = 33.
     sy = 54.
-    fftengine = FFT((nx, ny), fft='mpi', communicator=comm)
+    fftengine = FFT((nx, ny), engine='mpi', communicator=comm)
 
     surf = Topography(np.zeros(fftengine.nb_subdomain_grid_pts),
                       physical_sizes=(sx, sy),
